@@ -1,13 +1,12 @@
 # encoding: utf-8
-import datetime
 from south.db import db
 from south.v2 import SchemaMigration
-from django.db import models
+
 
 class Migration(SchemaMigration):
 
     def forwards(self, orm):
-        
+
         # Adding model 'Visit'
         db.create_table('visits_visit', (
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
@@ -23,13 +22,11 @@ class Migration(SchemaMigration):
         ))
         db.send_create_signal('visits', ['Visit'])
 
-
     def backwards(self, orm):
-        
+
         # Deleting model 'Visit'
         db.delete_table('visits_visit')
 
-
     models = {
         'visits.visit': {
             'Meta': {'ordering': "('uri', 'object_model', 'object_id')", 'object_name': 'Visit'},
